==> 0.0.4.tar.gz: test/nirrti_test.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:nirrti/nirrti.dart';

/// Used for testing only
void main() async {
  // Define a test. The TestWidgets function also provides a WidgetTester
  // to work with. The WidgetTester allows building and interacting
  // with widgets in the test environment.
  testWidgets('Testing widget...', (tester) async {
    // Create the widget by telling the tester to build it.
    await tester.pumpWidget(
      Material(
        child: Scaffold(
          body: Column(
            children: [
              OwlnextInput(
                controller: TextEditingController(),
                type: TextInputSubType.date,
                label: 'Test date input'
              ),
              OwlnextInput(
                controller: TextEditingController(),
                type: TextInputSubType.amount,
                label: 'Test amount input',
                amountMaxLimit: 69.420,
              ),
              OwlnextSelect(
                value: null,
                onChanged: (String value) => print(value),
                optionsRoute: () async => const [
                  DropdownMenuItem(value: 'coucou', child: Text('coucou'))
                ],
              ),
              OwlnextSelect(
                value: null,
                onChanged: (String value) => print(value),
                items: const [
                  DropdownMenuItem(value: 'coucou', child: Text('coucou'))
                ],
              )
            ],
          ),
        ),
      )
    );

    expect(tester.takeException(), isAssertionError);
  });
}

==> 0.0.82.tar.gz: test/nirrti_test.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:nirrti/nirrti.dart';

/// Used for testing only
void main() async {
  // Define a test. The TestWidgets function also provides a WidgetTester
  // to work with. The WidgetTester allows building and interacting
  // with widgets in the test environment.
  testWidgets('Testing widget...', (tester) async {
    // Create the widget by telling the tester to build it.
    await tester.pumpWidget(
      Material(
        child: Scaffold(
          body: Column(
            children: [
              OwlnextInput(
                controller: TextEditingController(),
                type: TextInputSubType.date,
                label: 'Test date input'
              ),
              OwlnextInput(
                controller: TextEditingController(),
                type: TextInputSubType.amount,
                label: 'Test amount input',
                amountMaxLimit: 69.420,
              ),
              OwlnextSelect(
                value: null,
                onChanged: (String value) => () {},
                optionsRoute: () async => const [
                  DropdownMenuItem(value: 'coucou', child: Text('coucou'))
                ],
              ),
              OwlnextSelect(
                value: null,
                onChanged: (String value) => () {},
                items: const [
                  DropdownMenuItem(value: 'coucou', child: Text('coucou'))
                ],
              ),
              OwlnextDropzone(
                fileUtils: FileUtils(),
              )
            ],
          ),
        ),
      )
    );

    expect(tester.takeException(), isAssertionError);
  });
}
